pub type Result<T> = Result<T, ProtocolError>;Expand description
A type alias for Result<T, ProtocolError>.
This is the standard result type used by all protocol operations.
Aliased Type
pub enum Result<T> {
Ok(T),
Err(ProtocolError),
}pub type Result<T> = Result<T, ProtocolError>;A type alias for Result<T, ProtocolError>.
This is the standard result type used by all protocol operations.
pub enum Result<T> {
Ok(T),
Err(ProtocolError),
}